# lantern-sl tool

This set of classes and utils are intended for an easy implementantion of solutions using Serverless Framework
It's really important to handle library versions properly, because we don't wanna break apps with any new change. 


# Installation

    $ pip install lantern-sl

# Usage
    

# Contributing

Usefull commands:

1. `sudo python setup develop`: Will install a local version of this source code, any change in the source code will be reflected locally

2. `tox`: Will run test cases in multiple python interpreters

# Deployment

1. install `twine` with (pip install twine or apt install twine)
2. Create a `~/.pypirc` file with the following content
3. Compile 
3. twine upload


[http://peterdowns.com/posts/first-time-with-pypi.html](http://peterdowns.com/posts/first-time-with-pypi.html)
